"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.burnToken = exports.getBurnTokenInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getBurnTokenInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['amount', s.u64()],
    ], { description: 'BurnTokenInstructionData' }), (value) => ({ ...value, discriminator: 8 }));
}
exports.getBurnTokenInstructionDataSerializer = getBurnTokenInstructionDataSerializer;
function burnToken(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA');
    const accountAccount = input.account;
    const mintAccount = input.mint;
    const authorityAccount = input.authority ?? context.identity;
    keys.push({
        pubkey: accountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(accountAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    const data = getBurnTokenInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.burnToken = burnToken;
//# sourceMappingURL=burnToken.js.map