"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAccountWithRent = exports.getCreateAccountWithRentInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getCreateAccountWithRentInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['space', s.u64()],
        ['programId', s.publicKey()],
    ], { description: 'CreateAccountWithRentInstructionData' }), (value) => ({ ...value, discriminator: 0 }));
}
exports.getCreateAccountWithRentInstructionDataSerializer = getCreateAccountWithRentInstructionDataSerializer;
function createAccountWithRent(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplSystemExtras', 'SysExL2WDyJi9aRZrXorrjHJut3JwHQ7R9bTyctbNNG');
    const payerAccount = input.payer ?? context.payer;
    const newAccountAccount = input.newAccount;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    signers.push(newAccountAccount);
    keys.push({
        pubkey: newAccountAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(newAccountAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    const data = getCreateAccountWithRentInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = Number(input.space) + umi_1.ACCOUNT_HEADER_SIZE;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.createAccountWithRent = createAccountWithRent;
//# sourceMappingURL=createAccountWithRent.js.map