"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLut = exports.getCreateLutInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getCreateLutInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u32()],
        ['recentSlot', s.u64()],
        ['bump', s.u8()],
    ], { description: 'CreateLutInstructionData' }), (value) => ({ ...value, discriminator: 0 }));
}
exports.getCreateLutInstructionDataSerializer = getCreateLutInstructionDataSerializer;
function createLut(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('splAddressLookupTable', 'AddressLookupTab1e1111111111111111111111111');
    const authorityAccount = input.authority ?? context.identity;
    const addressAccount = input.address ??
        (0, accounts_1.findAddressLookupTablePda)(context, {
            authority: (0, umi_1.publicKey)(authorityAccount),
            recentSlot: input.recentSlot,
        });
    const payerAccount = input.payer ?? context.payer;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    keys.push({
        pubkey: addressAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(addressAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    const data = getCreateLutInstructionDataSerializer(context).serialize({
        ...input,
        bump: addressAccount.bump,
    });
    const bytesCreatedOnChain = 56 + umi_1.ACCOUNT_HEADER_SIZE;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.createLut = createLut;
//# sourceMappingURL=createLut.js.map